/*#######################################################################################
 AVR Ansteuerung 10/12 Bit PC-Datenerfassung LTC1290
 
 Copyright:      Christian Truckenbrodt  mailto: trucki@web.de
				 Diese Routine darf nicht ohne mein Einverstndnis fr kommerzielle
				 Zwecke verwendet werden.

 Version:        01.03.2005
 
 System:		 WinAVR, Ponyprog2000, ATMEGA32@16MHZ, 2x16LCD an PORTC,
				 LCD u. UART Routine von Radig Ulrich.
				 
 Description:  	 Programm zur Ansteuerung des Conrad Bausatzes 10/12 Bit 
				 PC-Datenerfassung .
				 ATMEGA wird mittels 3 normalen IO PORTS an den LTC1290 angeschlossen.
				 Die Pins werden in LTC1290.h festgelegt.
				 
				 Die 10/12 Bit PC-Datenerfassung wird wie folgt mit dem ATMEGA32 verbunden:
				 
				 ---                              ---
				 A |PA0-----------DTR(D-SUB9 PIN4)| L
				 T |                              | T
				 M |PA1-----------RTS(D-SUB9 PIN7)| C
				 E |                              | 1
				 G |PA2-----------CTS(D-SUB9 PIN8)| 2  
				 A |                              | 9   
				 3 |GND-        +12V------UBextern| 0    
				 2 |   |-----------------------GND|     
				 ---   -                          ---  
				 
				 Der Schalter zur Wahl der Versorgungsspannung des LTC1290 muss auf
				 EXTERN gestellt werden. Wenn der Conrad Bausatz richtg versorgt wird, so
				 kann man am IC LT1021 an PIN2 die +12V Versorgungsspannung und an 
				 PIN6 die 5,000V Referenzspannung messen.
				 
				 Bevor der LTC1290 gelesen werden kann, muss die Routine LTC1290_Init()
				 aufgerufen werden. Anschlieend kann mit LTC1290_Read(kanal0-7) gemessen 
				 werden. Der gemessene Wert steht im Rckgabewert der Funktion. 
				 Siehe Beispiel.
				 
				 Ich hafte fr keinerlei Schden! Die Benutzung dieser Routine geschieht 
				 auf eigene Gefahr!
			 
#######################################################################################*/
#ifndef _LCT1290_H
 #define _LTC1290_H

extern void LTC1290_Init (void);
extern int LTC1290_Read (int);

#define LTC1290_Port_DDR			DDRA	//Port an dem der LTC1290 Conrad Bausatz angeschlossen wird
#define LTC1290_Port_Write			PORTA
#define LTC1290_Port_Read			PINA

#define LTC1290_DTR					0 		//Pin fr DTR
#define LTC1290_RTS					1		//Pin fr RTS
#define LTC1290_CTS					2 		//Pin fr CTS

#endif //_LTC1290_H






